@@ -2,8 +2,8 @@
 /*
  * cimXmlParser.c
  *
- * (C) Copyright IBM Corp. 2005
- * (C) Copyright Intel Corp. 2005
+ * © Copyright IBM Corp. 2005, 2007
+ * © Copyright Intel Corp. 2005
  *
  * THIS FILE IS PROVIDED UNDER THE TERMS OF THE ECLIPSE PUBLIC LICENSE
  * ("AGREEMENT"). ANY USE, REPRODUCTION OR DISTRIBUTION OF THIS FILE
@@ -26,25 +26,68 @@
 #include <cmcidt.h>
 
 #include "cimXmlParser.h"
-#include "cimXmlResp.h"
+#include "grammar.h"
 
 #ifdef DMALLOC
 #include "dmalloc.h"
 #endif
 
+#ifdef LARGE_VOL_SUPPORT
 
-int yylex(YYSTYPE * lvalp, ParserControl * parm);
-int yyerror(char *s);
+// New begin
+#include <curl/curl.h>         // new
+#include <pthread.h>           // new
+#include <time.h>              // new
+#include <sys/time.h>          // new
+#include <setjmp.h>            // new
+
+struct _CMCIConnectionFT;                           // new 
+typedef struct _CMCIConnectionFT CMCIConnectionFT;  // new
+
+char * getNextSection(struct _CMCIConnection * ) ;
+int checkTag(char * , int ) ;
+
+#include "cmci.h"
+#include "utilStringBuffer.h"  // new
+#include "cimXmlParser.h"      // new
+#include "native.h"            // new
+#include "esinfo.h"            // new
+#include "conn.h"              // new
+
+jmp_buf save_env ;
+
+/*
+ * response data helper functions.
+ */
+inline char * CURPTR (enumScanInfo * esi ){
+ return(((char*)(esi->base)) + (esi->curoff)) ;
+}
+inline char * SSECPTR (enumScanInfo * esi ){
+ return(((char*)(esi->base)) + (esi->ssecoff)) ;
+}
+inline char * LASTPTR (enumScanInfo * esi ){
+ return(((char*)(esi->base)) + (esi->eodoff)) ;
+}
+inline void INCOFF (enumScanInfo * esi ){
+ (esi->curoff)++ ;  	
+}
+
+int sfccFreeSection(ParserControl * );
+void * enumScanThrd(struct native_enum *);
+int sfccLex(parseUnion * , ParserControl * );
+char * getNextSection(struct _CMCIConnection * );
+int checkTag(char * , int );
+
+#endif /* endif LARGE_VOL_SUPPORT */
 
 static int attrsOk(XmlBuffer * xb, const XmlElement * e, XmlAttr * r,
                    const char *tag, int etag);
 static char *getValue(XmlBuffer * xb, const char *v);
-extern int yyparse(void *);
 
 typedef struct tags {
    const char *tag;
    const int tagLen;
-   int (*process) (YYSTYPE *, ParserControl * parm);
+   int (*process) (parseUnion *, ParserControl * parm);
    int etag;
 } Tags;
 
@@ -60,8 +103,10 @@ static void Throw(XmlBuffer * xb, char *msg)
 static XmlBuffer *newXmlBuffer(const char *s)
 {
    XmlBuffer *xb = (XmlBuffer *) malloc(sizeof(XmlBuffer));
-   xb->base = xb->cur = (char *) strdup(s);
-   xb->last = xb->cur + strlen(xb->cur);
+   if(s){
+      xb->base = xb->cur = (char *) strdup(s);
+      xb->last = xb->cur + strlen(xb->cur);
+   }
    xb->nulledChar = 0;
    xb->eTagFound = 0;
    xb->etag = 0;
@@ -70,7 +115,8 @@ static XmlBuffer *newXmlBuffer(const char *s)
 
 static void releaseXmlBuffer(XmlBuffer *xb)
 {
-    free (xb->base);
+	  if(xb->base)
+       free (xb->base);
     free (xb);
 }
 
@@ -323,9 +369,7 @@ char * cmpiToXmlType(CMPIType cmpiType)
     return NULL;
 }
 
-//static XmlBuffer* xmb;
-
-static int procXml(YYSTYPE * lvalp, ParserControl * parm)
+static int procXml(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = { {"version"},
    {"encoding"},
@@ -342,7 +386,7 @@ static int procXml(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procCim(YYSTYPE * lvalp, ParserControl * parm)
+static int procCim(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {"CIMVERSION"},
@@ -353,13 +397,14 @@ static int procCim(YYSTYPE * lvalp, ParserControl * parm)
 
    memset(attr, 0, sizeof(attr));
    if (tagEquals(parm->xmb, "CIM")) {
-      if (attrsOk(parm->xmb, elm, attr, "CIM", ZTOK_CIM))
+      if (attrsOk(parm->xmb, elm, attr, "CIM", ZTOK_CIM)){
          return XTOK_CIM;
+      }
    }
    return 0;
 }
 
-static int procMessage(YYSTYPE * lvalp, ParserControl * parm)
+static int procMessage(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {"ID"},
@@ -379,7 +424,7 @@ static int procMessage(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procSimpleResp(YYSTYPE * lvalp, ParserControl * parm)
+static int procSimpleResp(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {NULL}
@@ -392,7 +437,7 @@ static int procSimpleResp(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procIMethodResp(YYSTYPE * lvalp, ParserControl * parm)
+static int procIMethodResp(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {"NAME"},
@@ -403,7 +448,7 @@ static int procIMethodResp(YYSTYPE * lvalp, ParserControl * parm)
    memset(attr, 0, sizeof(attr));
    if (tagEquals(parm->xmb, "IMETHODRESPONSE")) {
       if (attrsOk(parm->xmb, elm, attr, "IMETHODRESPONSE", ZTOK_IMETHODRESP)) {
-         lvalp->xtokMessage.id = attr[0].attr;
+         /*lvalp->xtokMessage.id = attr[0].attr;*/
          parm->respHdr.id = attr[0].attr;
          return XTOK_IMETHODRESP;
       }
@@ -411,7 +456,7 @@ static int procIMethodResp(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procMethodResp(YYSTYPE * lvalp, ParserControl * parm)
+static int procMethodResp(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {"NAME"},
@@ -422,7 +467,8 @@ static int procMethodResp(YYSTYPE * lvalp, ParserControl * parm)
    memset(attr, 0, sizeof(attr));
    if (tagEquals(parm->xmb, "METHODRESPONSE")) {
       if (attrsOk(parm->xmb, elm, attr, "METHODRESPONSE", ZTOK_METHODRESP)) {
-         lvalp->xtokMessage.id = attr[0].attr;
+         memset(&lvalp->xtokMethodRespContent, 0, sizeof(XtokMethodRespContent));
+         lvalp->xtokMethodRespContent.name = attr[0].attr;
          parm->respHdr.id = attr[0].attr;
          return XTOK_METHODRESP;
       }
@@ -431,7 +477,7 @@ static int procMethodResp(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procErrorResp(YYSTYPE * lvalp, ParserControl * parm)
+static int procErrorResp(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {"CODE"},
@@ -451,7 +497,7 @@ static int procErrorResp(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procIRetValue(YYSTYPE * lvalp, ParserControl * parm)
+static int procIRetValue(parseUnion * lvalp, ParserControl * parm)
 {
    if (tagEquals(parm->xmb, "IRETURNVALUE")) {
       static XmlElement elm[] = {
@@ -466,14 +512,15 @@ static int procIRetValue(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procRetValue(YYSTYPE * lvalp, ParserControl * parm)
+static int procRetValue(parseUnion * lvalp, ParserControl * parm)
 {
    if (tagEquals(parm->xmb, "RETURNVALUE")) {
       static XmlElement elm[] = {
          {"PARAMTYPE"},
+         {"EMBEDDEDOBJECT"},
          {NULL}
       };
-      XmlAttr attr[2];
+      XmlAttr attr[3];
       int i;
       memset(attr, 0, sizeof(attr));
       if (attrsOk(parm->xmb, elm, attr, "RETURNVALUE", ZTOK_RETVALUE)) {
@@ -487,7 +534,7 @@ static int procRetValue(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procLocalNameSpacePath(YYSTYPE * lvalp, ParserControl * parm)
+static int procLocalNameSpacePath(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {NULL}
@@ -497,13 +544,14 @@ static int procLocalNameSpacePath(YYSTYPE * lvalp, ParserControl * parm)
       if (attrsOk
           (parm->xmb, elm, attr, "LOCALNAMESPACEPATH",
            ZTOK_LOCALNAMESPACEPATH)) {
+         lvalp->xtokLocalNameSpacePath.value = NULL;
          return XTOK_LOCALNAMESPACEPATH;
       }
    }
    return 0;
 }
 
-static int procClassPath(YYSTYPE * lvalp, ParserControl * parm)
+static int procClassPath(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {NULL}
@@ -519,7 +567,7 @@ static int procClassPath(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procLocalClassPath(YYSTYPE * lvalp, ParserControl * parm)
+static int procLocalClassPath(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {NULL}
@@ -535,7 +583,7 @@ static int procLocalClassPath(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procLocalInstancePath(YYSTYPE * lvalp, ParserControl * parm)
+static int procLocalInstancePath(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {NULL}
@@ -551,7 +599,7 @@ static int procLocalInstancePath(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procObjectPath(YYSTYPE * lvalp, ParserControl * parm)
+static int procObjectPath(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {NULL}
@@ -560,14 +608,13 @@ static int procObjectPath(YYSTYPE * lvalp, ParserControl * parm)
    if (tagEquals(parm->xmb, "OBJECTPATH")) {
       if (attrsOk(parm->xmb, elm, attr, "OBJECTPATH",
            ZTOK_OBJECTPATH)) {
-         lvalp->xtokValue.value = getContent(parm->xmb);
          return XTOK_OBJECTPATH;
       }
    }
    return 0;
 }
 
-static int procNameSpace(YYSTYPE * lvalp, ParserControl * parm)
+static int procNameSpace(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {"NAME"},
@@ -585,14 +632,15 @@ static int procNameSpace(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procParamValue(YYSTYPE * lvalp, ParserControl * parm)
+static int procParamValue(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {"NAME"},
       {"PARAMTYPE"},
+      {"EMBEDDEDOBJECT"},
       {NULL}
    };
-   XmlAttr attr[2];
+   XmlAttr attr[3];
    int i, m;
 
    memset(attr, 0, sizeof(attr));
@@ -609,7 +657,7 @@ static int procParamValue(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procClassName(YYSTYPE * lvalp, ParserControl * parm)
+static int procClassName(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {"NAME"},
@@ -620,14 +668,14 @@ static int procClassName(YYSTYPE * lvalp, ParserControl * parm)
    memset(attr, 0, sizeof(attr));
    if (tagEquals(parm->xmb, "CLASSNAME")) {
       if (attrsOk(parm->xmb, elm, attr, "CLASSNAME", ZTOK_CLASSNAME)) {
-         lvalp->className = attr[0].attr;
+         lvalp->xtokClassName.value = attr[0].attr;
          return XTOK_CLASSNAME;
       }
    }
    return 0;
 }
 
-static int procInstanceName(YYSTYPE * lvalp, ParserControl * parm)
+static int procInstanceName(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {"CLASSNAME"},
@@ -638,6 +686,7 @@ static int procInstanceName(YYSTYPE * lvalp, ParserControl * parm)
    memset(attr, 0, sizeof(attr));
    if (tagEquals(parm->xmb, "INSTANCENAME")) {
       if (attrsOk(parm->xmb, elm, attr, "INSTANCENAME", ZTOK_INSTANCENAME)) {
+         memset(&lvalp->xtokInstanceName, 0, sizeof(XtokInstanceName));
          lvalp->xtokInstanceName.className = attr[0].attr;
          return XTOK_INSTANCENAME;
       }
@@ -645,7 +694,7 @@ static int procInstanceName(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procKeyBinding(YYSTYPE * lvalp, ParserControl * parm)
+static int procKeyBinding(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {"NAME"},
@@ -656,14 +705,14 @@ static int procKeyBinding(YYSTYPE * lvalp, ParserControl * parm)
    memset(attr, 0, sizeof(attr));
    if (tagEquals(parm->xmb, "KEYBINDING")) {
       if (attrsOk(parm->xmb, elm, attr, "KEYBINDING", ZTOK_KEYBINDING)) {
-         lvalp->xtokInstanceName.className = attr[0].attr;
+         lvalp->xtokKeyBinding.name = attr[0].attr;
          return XTOK_KEYBINDING;
       }
    }
    return 0;
 }
 
-static int procInstance(YYSTYPE * lvalp, ParserControl * parm)
+static int procInstance(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {"CLASSNAME"},
@@ -674,6 +723,7 @@ static int procInstance(YYSTYPE * lvalp, ParserControl * parm)
    memset(attr, 0, sizeof(attr));
    if (tagEquals(parm->xmb, "INSTANCE")) {
       if (attrsOk(parm->xmb, elm, attr, "INSTANCE", ZTOK_INSTANCE)) {
+         memset(&lvalp->xtokInstance, 0, sizeof(XtokInstance));
          lvalp->xtokInstance.className = attr[0].attr;
          return XTOK_INSTANCE;
       }
@@ -681,7 +731,7 @@ static int procInstance(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procClass(YYSTYPE * lvalp, ParserControl * parm)
+static int procClass(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {"NAME"},
@@ -693,6 +743,7 @@ static int procClass(YYSTYPE * lvalp, ParserControl * parm)
    memset(attr, 0, sizeof(attr));
    if (tagEquals(parm->xmb, "CLASS")) {
       if (attrsOk(parm->xmb, elm, attr, "CLASS", ZTOK_CLASS)) {
+         memset(&lvalp->xtokClass, 0, sizeof(XtokClass));
          lvalp->xtokClass.className = attr[0].attr;
          lvalp->xtokClass.superClass = attr[1].attr;
          return XTOK_CLASS;
@@ -701,7 +752,7 @@ static int procClass(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procKeyValue(YYSTYPE * lvalp, ParserControl * parm)
+static int procKeyValue(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {"VALUETYPE"},
@@ -724,7 +775,7 @@ static int procKeyValue(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procHost(YYSTYPE * lvalp, ParserControl * parm)
+static int procHost(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {NULL}
@@ -739,7 +790,7 @@ static int procHost(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procValue(YYSTYPE * lvalp, ParserControl * parm)
+static int procValue(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {NULL}
@@ -749,14 +800,14 @@ static int procValue(YYSTYPE * lvalp, ParserControl * parm)
       char *v;
       if (attrsOk(parm->xmb, elm, attr, "VALUE", ZTOK_VALUE)) {
          v=getContent(parm->xmb);
-         lvalp->xtokValue.value = v;
+         lvalp->xtokValue.data.value = v;
          return XTOK_VALUE;
       }
    }
    return 0;
 }
 
-static int procValueArray(YYSTYPE * lvalp, ParserControl * parm)
+static int procValueArray(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {NULL}
@@ -765,13 +816,34 @@ static int procValueArray(YYSTYPE * lvalp, ParserControl * parm)
    if (tagEquals(parm->xmb, "VALUE.ARRAY")) {
       if (attrsOk(parm->xmb, elm, attr, "VALUE.ARRAY",
            ZTOK_VALUEARRAY)) {
+         lvalp->xtokValueArray.max = 16;
+         lvalp->xtokValueArray.next = 0;
+         lvalp->xtokValueArray.values = (char**)parser_malloc(parm->heap, (sizeof(char*) * lvalp->xtokValueArray.max));
          return XTOK_VALUEARRAY;
       }
    }
    return 0;
 }
 
-static int procValueNamedInstance(YYSTYPE * lvalp, ParserControl * parm)
+static int procValueRefArray(parseUnion * lvalp, ParserControl * parm)
+{
+   static XmlElement elm[] = {
+      {NULL}
+   };
+   XmlAttr attr[1];
+   if (tagEquals(parm->xmb, "VALUE.REFARRAY")) {
+      if (attrsOk(parm->xmb, elm, attr, "VALUE.REFARRAY",
+           ZTOK_VALUEARRAY)) {
+         lvalp->xtokValueRefArray.max = 16;
+         lvalp->xtokValueRefArray.next = 0;
+         lvalp->xtokValueRefArray.values = (XtokValueReference*)parser_malloc(parm->heap, (sizeof(XtokValueReference) * lvalp->xtokValueRefArray.max));
+         return XTOK_VALUEREFARRAY;
+      }
+   }
+   return 0;
+}
+
+static int procValueNamedInstance(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {NULL}
@@ -780,14 +852,13 @@ static int procValueNamedInstance(YYSTYPE * lvalp, ParserControl * parm)
    if (tagEquals(parm->xmb, "VALUE.NAMEDINSTANCE")) {
       if (attrsOk(parm->xmb, elm, attr, "VALUE.NAMEDINSTANCE",
            ZTOK_VALUENAMEDINSTANCE)) {
-         lvalp->xtokValue.value = getContent(parm->xmb);
          return XTOK_VALUENAMEDINSTANCE;
       }
    }
    return 0;
 }
 
-static int procInstancePath(YYSTYPE * lvalp, ParserControl * parm)
+static int procInstancePath(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {NULL}
@@ -796,14 +867,13 @@ static int procInstancePath(YYSTYPE * lvalp, ParserControl * parm)
    if (tagEquals(parm->xmb, "INSTANCEPATH")) {
       if (attrsOk(parm->xmb, elm, attr, "INSTANCEPATH",
            ZTOK_INSTANCEPATH)) {
-         lvalp->xtokValue.value = getContent(parm->xmb);
          return XTOK_INSTANCEPATH;
       }
    }
    return 0;
 }
 
-static int procNameSpacePath(YYSTYPE * lvalp, ParserControl * parm)
+static int procNameSpacePath(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {NULL}
@@ -812,14 +882,13 @@ static int procNameSpacePath(YYSTYPE * lvalp, ParserControl * parm)
    if (tagEquals(parm->xmb, "NAMESPACEPATH")) {
       if (attrsOk(parm->xmb, elm, attr, "NAMESPACEPATH",
            ZTOK_NAMESPACEPATH)) {
-         lvalp->xtokValue.value = getContent(parm->xmb);
          return XTOK_NAMESPACEPATH;
       }
    }
    return 0;
 }
 
-static int procValueReference(YYSTYPE * lvalp, ParserControl * parm)
+static int procValueReference(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {NULL}
@@ -828,14 +897,13 @@ static int procValueReference(YYSTYPE * lvalp, ParserControl * parm)
    if (tagEquals(parm->xmb, "VALUE.REFERENCE")) {
       if (attrsOk(parm->xmb, elm, attr, "VALUE.REFERENCE",
            ZTOK_VALUEREFERENCE)) {
-         lvalp->xtokValue.value = getContent(parm->xmb);
          return XTOK_VALUEREFERENCE;
       }
    }
    return 0;
 }
 
-static int procValueObjectWithPath(YYSTYPE * lvalp, ParserControl * parm)
+static int procValueObjectWithPath(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = {
       {NULL}
@@ -850,7 +918,7 @@ static int procValueObjectWithPath(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procQualifier(YYSTYPE * lvalp, ParserControl * parm)
+static int procQualifier(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = { {"NAME"},
    {"TYPE"},
@@ -889,15 +957,16 @@ static int procQualifier(YYSTYPE * lvalp, ParserControl * parm)
 }
 
 
-static int procProperty(YYSTYPE * lvalp, ParserControl * parm)
+static int procProperty(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = { {"NAME"},
    {"TYPE"},
    {"CLASSORIGIN"},
    {"PROPAGATED"},
+   {"EMBEDDEDOBJECT"},
    {NULL}
    };
-   XmlAttr attr[4];
+   XmlAttr attr[5];
    int i, m;
 
    memset(attr, 0, sizeof(attr));
@@ -920,21 +989,23 @@ static int procProperty(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procPropertyArray(YYSTYPE * lvalp, ParserControl * parm)
+static int procPropertyArray(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elmPA[] = { {"NAME"},
    {"TYPE"},
    {"CLASSORIGIN"},
    {"PROPAGATED"},
    {"ARRAYSIZE"},
+   {"EMBEDDEDOBJECT"},
    {NULL}
    };
-   XmlAttr attr[5];
+   XmlAttr attr[6];
    int i, m;
 
    memset(attr, 0, sizeof(attr));
    if (tagEquals(parm->xmb, "PROPERTY.ARRAY")) {
       if (attrsOk(parm->xmb, elmPA, attr, "PROPERTY.ARRAY", ZTOK_PROPERTYARRAY)) {
+         memset(&lvalp->xtokProperty, 0, sizeof(XtokProperty));
          lvalp->xtokProperty.name = attr[0].attr;
          lvalp->xtokProperty.valueType = CMPI_null;
          if (attr[1].attr)
@@ -951,7 +1022,7 @@ static int procPropertyArray(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procPropertyReference(YYSTYPE * lvalp, ParserControl * parm)
+static int procPropertyReference(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = { {"NAME"},
    {"REFERENCECLASS"},
@@ -979,7 +1050,7 @@ static int procPropertyReference(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procMethod(YYSTYPE * lvalp, ParserControl * parm)
+static int procMethod(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] = { {"NAME"},
    {"TYPE"},
@@ -1008,7 +1079,7 @@ static int procMethod(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procParam(YYSTYPE * lvalp, ParserControl * parm)
+static int procParam(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] =
    { {"NAME"},
@@ -1034,7 +1105,7 @@ static int procParam(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procParamArray(YYSTYPE * lvalp, ParserControl * parm)
+static int procParamArray(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] =
    { {"NAME"},
@@ -1062,7 +1133,7 @@ static int procParamArray(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procParamRef(YYSTYPE * lvalp, ParserControl * parm)
+static int procParamRef(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] =
    { {"NAME"},
@@ -1086,7 +1157,7 @@ static int procParamRef(YYSTYPE * lvalp, ParserControl * parm)
    return 0;
 }
 
-static int procParamRefArray(YYSTYPE * lvalp, ParserControl * parm)
+static int procParamRefArray(parseUnion * lvalp, ParserControl * parm)
 {
    static XmlElement elm[] =
    { {"NAME"},
@@ -1099,20 +1170,100 @@ static int procParamRefArray(YYSTYPE * lvalp, ParserControl * parm)
    memset(attr, 0, sizeof(attr));
    if (tagEquals(parm->xmb, "PARAMETER.REFARRAY")) {
       attr[1].attr = NULL;
-      if (attrsOk(parm->xmb, elm, attr, "PARAMETER.REFARRAY", ZTOK_PARAM)) {
+      if (attrsOk(parm->xmb, elm, attr, "PARAMETER.REFARRAY", ZTOK_PARAMREFARRAY)) {
          memset(&lvalp->xtokParam, 0, sizeof(XtokParam));
          lvalp->xtokParam.pType = ZTOK_PARAMREFARRAY;
          lvalp->xtokParam.name = attr[0].attr;
          lvalp->xtokParam.refClass = attr[1].attr;
          lvalp->xtokParam.arraySize = attr[2].attr;
          lvalp->xtokParam.type = CMPI_refA;
-         return XTOK_PARAM;
+         return XTOK_PARAMREFARRAY;
       }
    }
    return 0;
 }
 
 
+static int procSimpleExpReq(parseUnion * lvalp, ParserControl * parm)
+{
+   static XmlElement elm[] = {
+      {NULL}
+   };
+   XmlAttr   attr[1];
+
+   if (tagEquals(parm->xmb, "SIMPLEEXPREQ")) {
+      if (attrsOk(parm->xmb, elm, attr, "SIMPLEEXPREQ", ZTOK_SIMPLEEXPREQ))
+      {
+         return XTOK_SIMPLEEXPREQ;
+      }
+   }
+   return 0;
+}
+
+static int procExportMethodCall(parseUnion * lvalp, ParserControl * parm)
+{
+   static XmlElement elm[] = {
+     {"NAME"},
+      {NULL}
+   };
+   XmlAttr   attr[1];
+
+   memset(attr, 0, sizeof(attr));
+   if (tagEquals(parm->xmb, "EXPMETHODCALL")) {
+      if (attrsOk(parm->xmb, elm, attr, "EXPMETHODCALL", ZTOK_EXPMETHODCALL)) {
+         if (strcasecmp(attr[0].attr, "ExportIndication") == 0) {
+            return XTOK_EXPORTINDICATION;
+         }
+      }
+   }
+   return 0;
+}
+
+static int procExParamValue(parseUnion * lvalp, ParserControl * parm)
+{
+   static XmlElement elm[] = {
+     {"NAME"},
+      {NULL}
+   };
+   XmlAttr   attr[1];
+
+   memset(attr, 0, sizeof(attr));
+   if (tagEquals(parm->xmb, "EXPPARAMVALUE")) {
+      if (attrsOk(parm->xmb, elm, attr, "EXPPARAMVALUE", ZTOK_EXPPARAMVALUE)) {
+         if (strcasecmp(attr[0].attr, "NewIndication") == 0) {
+            return XTOK_EP_INSTANCE;
+         }
+      }
+   }
+   return 0;
+}
+
+static int procCdata(parseUnion * lvalp, ParserControl * parm)
+{
+   static XmlElement elm[] = {
+      {NULL}
+   };
+   XmlAttr attr[1];
+   
+   if (tagEquals(parm->xmb, "![CDATA[")) {
+      parm->xmb->cur--;
+      parm->xmb->cur[0] = '>';      
+      char *v;
+      if (attrsOk(parm->xmb, elm, attr, "![CDATA[", ZTOK_CDATA)) {
+         
+         v=strstr(parm->xmb->cur, "]]>");
+         if(v) {
+            v[0] = '<';
+            v[1] = '/';
+         } else {
+            return 0;
+         }
+         return XTOK_CDATA;
+      }
+   }
+   return 0;
+}
+
 static Tags tags[] = {
    {TAG("?xml"), procXml, ZTOK_XML},
    {TAG("CIM"), procCim, ZTOK_CIM},
@@ -1152,11 +1303,23 @@ static Tags tags[] = {
    {TAG("OBJECTPATH"), procObjectPath, ZTOK_OBJECTPATH},
    {TAG("METHODRESPONSE"), procMethodResp, ZTOK_METHODRESP},
    {TAG("RETURNVALUE"), procRetValue, ZTOK_RETVALUE},
-   {TAG("CLASSPATH"), procClassPath, ZTOK_CLASSPATH}
+   {TAG("CLASSPATH"), procClassPath, ZTOK_CLASSPATH},
+   {TAG("SIMPLEEXPREQ"), procSimpleExpReq, ZTOK_SIMPLEEXPREQ},
+   {TAG("EXPMETHODCALL"), procExportMethodCall, ZTOK_EXPMETHODCALL},
+   {TAG("EXPPARAMVALUE"), procExParamValue, ZTOK_EXPPARAMVALUE},
+   {TAG("![CDATA["), procCdata, ZTOK_CDATA},
+   {TAG(""), procCdata, ZTOK_CDATA},
+   /* The last two lines are a hack for embedded instances. The CDATA
+    * construct does not have a <x> ... </x> form but rather something like
+    * <bla ....>, which is not a real tag. so the second line is necessary
+    * for our lexer to find the closing "tag" for that case, which is just
+    * an empty string */
 };
 #define TAGS_NITEMS	(int)(sizeof(tags)/sizeof(Tags))
 
-int yylex(YYSTYPE * lvalp, ParserControl * parm)
+#ifndef LARGE_VOL_SUPPORT
+
+int sfccLex(parseUnion * lvalp, ParserControl * parm)
 {
    int i, rc;
    char *next;
@@ -1198,19 +1361,11 @@ int yylex(YYSTYPE * lvalp, ParserControl * parm)
    }
    return 0;
 }
-
-int yyerror(char *s)
-{
-   printf("*-* yyerror: %s\n", s);
-   exit(5);
-}
+#endif
 
 ResponseHdr scanCimXmlResponse(const char *xmlData, CMPIObjectPath *cop)
 {
    ParserControl control;
-   XtokParamValue *outParam=NULL;
-   CMPIArgs *args = NULL;
-   CMPIValue value;
 #if DEBUG
    extern int do_debug;
 
@@ -1225,36 +1380,14 @@ ResponseHdr scanCimXmlResponse(const char *xmlData, CMPIObjectPath *cop)
    control.respHdr.xmlBuffer = xmb;
 
    control.respHdr.rvArray=newCMPIArray(0,0,NULL);
-   control.da_nameSpace=(char*)getNameSpaceChars(cop);
+
+   if(cop) {
+       control.da_nameSpace=(char*)getNameSpaceChars(cop);
+   }
 
    control.heap = parser_heap_init();
 
-   control.respHdr.rc = yyparse(&control);
-
-   /* Process OUT parameters */
-   outParam = control.paramValues.first;
-
-   if (outParam) { 
-
-       args = newCMPIArgs(NULL);
-
-       while (outParam) {
-
-           /*value = (outParam->type == CMPI_ref) 
-               ? str2CMPIValue(outParam->type, NULL, &outParam->valueRef)
-               : str2CMPIValue(outParam->type, outParam->value.value, NULL);*/
-           value = str2CMPIValue(outParam->type, outParam->value.value, &outParam->valueRef);
-
-           /* Add it to the args list */
-           args->ft->addArg ( args, outParam->name, &value, outParam->type);
-	   native_release_CMPIValue(outParam->type,&value);
-           outParam = outParam->next;
-       }
-       control.respHdr.outArgs = args;
-       /* Note : Freeing of list will be done by
-        * parser_heap_term() routine.
-        */
-   }
+   control.respHdr.rc = startParsing(&control);
 
    parser_heap_term(control.heap);
 
@@ -1347,3 +1480,351 @@ void* parser_strdup(ParserHeap *ph, const char *s)
   }
 }
 
+#if LARGE_VOL_SUPPORT
+
+/* **************************************************************************/
+/* **************************************************************************/
+/* **************************************************************************/
+/* **************************************************************************/
+/* **************************************************************************/
+/* **************************************************************************/
+/* **************************************************************************/
+int sfccFreeSection(ParserControl * parm)
+{
+   if(parm->econ->asynRCntl.escanInfo.section){  	              
+	    free(parm->econ->asynRCntl.escanInfo.section) ;
+		  parm->econ->asynRCntl.escanInfo.section = NULL ;
+   }	
+}
+#define TIMEDELAY 10 
+void * enumScanThrd(struct native_enum *NatEnum)
+{
+   CMCIConnection * con = NatEnum->econ ; /* enumeration */
+   CMPIObjectPath * cop = NatEnum->ecop ; /* enumeration */ 
+   
+   struct          timespec tp ;
+	 int             rc = 0 ;
+   
+   ParserControl control;
+   struct native_enum  *local_enmp ;
+   
+   memset(&control,0,sizeof(control));
+  
+   /* 
+    * get the data array and save a copy of address in enumeration 
+    */
+    
+   XmlBuffer *xmb = newXmlBuffer(NULL);
+   control.xmb = xmb;
+   control.respHdr.xmlBuffer = xmb;
+    
+   control.respHdr.rvArray=newCMPIArray(0,0,NULL);
+
+   local_enmp = con->asynRCntl.enmp ;
+   
+   local_enmp->data = control.respHdr.rvArray ;
+   
+   if(cop) {
+       control.da_nameSpace=(char*)getNameSpaceChars(cop);
+   }
+
+   control.heap = parser_heap_init();
+
+   control.econ = con ;
+     
+   if(rc = setjmp(save_env)) {
+      printf(" we had a timeout , we are going to exit from here \n") ;
+      con->asynRCntl.escanInfo.parsestate = PARSTATE_SERVER_TIMEOUT ;
+      con->asynRCntl.xfer_state = XFER_ERROR ;
+      return ;
+   }
+   
+   /*
+    * wait for first data block received or xfer complete
+    * we need to have some data before starting
+    */
+   while((con->asynRCntl.xfer_state != XFER_DATA_RECVD )&&
+         (con->asynRCntl.xfer_state != XFER_COMPLETE)){
+    	usleep(100000) ;
+   }
+       
+   control.respHdr.rc = startParsing(&control);
+     
+   /*
+    * releaseXmlBuffer free's that last con->asynRCntl.escanInfo.section 
+    * we clear out that pointer just to be safe
+    */
+   releaseXmlBuffer(xmb);
+   
+   con->asynRCntl.escanInfo.section = 0 ;
+   
+   parser_heap_term(control.heap);
+   
+   con->asynRCntl.escanInfo.parsestate = PARSTATE_COMPLETE ;
+    
+}
+
+int sfccLex(parseUnion * lvalp, ParserControl * parm)
+{
+   int i, rc;
+   char *next;
+   char *nextSection ;
+
+   for (;;) {
+   	
+   	  if(parm->econ) {
+   	     
+   	     if(parm->econ->asynRCntl.escanInfo.getnew == 1 ){
+            
+            nextSection = getNextSection(parm->econ) ;
+            if(nextSection != NULL) {
+               parm->xmb->base = nextSection ;
+               parm->xmb->cur  = nextSection ;
+               parm->xmb->last = nextSection + (parm->econ->asynRCntl.escanInfo.sectlen) ;
+
+         } else {
+     	      printf(" sfccLex --- section is NULL !!!!!!!!!!!!!!!!! \n") ;
+         }
+         }
+      }
+      
+      
+      next = nextTag(parm->xmb);
+      if (next == NULL) {
+         return 0;
+      }
+//      fprintf(stderr,"--- token: %.32s\n",next); //usefull for debugging
+      if (parm->xmb->eTagFound) {
+         parm->xmb->eTagFound = 0;
+         return parm->xmb->etag;
+      }
+
+      if (*next == '/') {
+         for (i = 0; i < TAGS_NITEMS; i++) {
+            if (nextEquals(next + 1, tags[i].tag, tags[i].tagLen) == 1) {
+               skipTag(parm->xmb);
+               return tags[i].etag;
+            }
+         }
+      }
+
+      else {
+         if (strncmp(parm->xmb->cur, "<!--", 4) == 0) {
+            parm->xmb->cur = strstr(parm->xmb->cur, "-->") + 3;
+            continue;
+         } else
+         if (strncmp(parm->xmb->cur, "<EC>", 4) == 0) {
+            parm->econ->asynRCntl.escanInfo.getnew = 1 ;
+            parm->econ->asynRCntl.escanInfo.parsestate = PARSTATE_STARTED ; 
+            continue;
+         } 
+         for (i = 0; i < TAGS_NITEMS; i++) {
+            if (nextEquals(next, tags[i].tag, tags[i].tagLen) == 1) {
+//	       printf("+++ %d\n",i);
+               rc=tags[i].process(lvalp, parm);
+               return rc;
+            }
+         }
+      }
+      break;
+   }
+   return 0;
+}
+
+char * getNextSection(struct _CMCIConnection * con)
+{
+	char * xmlb    = NULL;
+  char * workptr = NULL;
+  char * curptr  = NULL;
+  int    xmlblen = 0;
+  int    tagval  = 0;
+  int    retcode = 0; 
+  int    toval   = 0;
+  
+   /*
+    * free that old buffer 
+    */
+  
+  if(con->asynRCntl.escanInfo.section != NULL) {
+     free(con->asynRCntl.escanInfo.section);
+     con->asynRCntl.escanInfo.section = NULL ;
+  }
+  
+  if((retcode = pthread_mutex_lock(&(con->asynRCntl.escanlock))) != 0){
+     printf(" getNextSection pthread lock return code %d\n",retcode) ;	
+  }
+  
+  /*
+   * If we have no more new data from the server , we 
+   * unlock and sleep then check till we see that we have 
+   * received new data 
+   */
+  
+  while(con->asynRCntl.escanInfo.prevtotl == con->asynRCntl.escanInfo.recdtotl){
+     if((retcode = pthread_mutex_unlock(&(con->asynRCntl.escanlock))) != 0){
+        printf(" getNextSection pthread lock return code %d\n",retcode) ;	
+     }
+     /* *******************************************
+      * ******************************************* 
+      * timeout toval keeps us from hanging forever
+      * *******************************************
+      * *******************************************
+      */
+     usleep(1000) ;
+     toval++ ;
+
+     if(toval>5000) 
+         longjmp (save_env, 1);
+     
+     if(con->asynRCntl.escanInfo.prevtotl != con->asynRCntl.escanInfo.recdtotl){
+     	  /* 
+     	   * we got more data , exit this loop
+     	   */
+        if((retcode = pthread_mutex_lock(&(con->asynRCntl.escanlock))) != 0){
+             printf(" getNextSection pthread lock return code %d\n",retcode) ;	
+        }
+        break;
+     }   
+  }
+
+  if((con->asynRCntl.xfer_state == XFER_DATA_RECVD) ||
+     (con->asynRCntl.xfer_state == XFER_COMPLETE)	)    {
+
+     workptr = LASTPTR(&(con->asynRCntl.escanInfo)) ;
+     curptr  = CURPTR(&(con->asynRCntl.escanInfo));
+  
+     con->asynRCntl.escanInfo.ssecoff = con->asynRCntl.escanInfo.curoff ;
+     
+     toval = 0;
+     while(workptr > curptr) {   
+        if(*workptr == '>'){
+        	 tagval = checkTag(workptr , con->asynRCntl.eMethodType) ;
+        	 if(tagval == 0){
+              con->asynRCntl.escanInfo.curoff = con->asynRCntl.escanInfo.curoff + (workptr - curptr) + 1 ;
+              xmlblen = ((workptr - curptr) + 5) ;
+           
+              xmlb = malloc(xmlblen + 64) ;
+              con->asynRCntl.escanInfo.section = xmlb ;
+
+              con->asynRCntl.escanInfo.sectlen = xmlblen + 5 ;
+              memset(xmlb , 0x0cc , xmlblen + 5) ;
+                                   
+              if(xmlb != NULL){
+                 memcpy(xmlb , SSECPTR(&con->asynRCntl.escanInfo) , xmlblen) ;
+                 strcpy((xmlb+(xmlblen - 4)) , "<EC>") ;
+                 con->asynRCntl.escanInfo.getnew = 0 ;
+ 
+              } else {
+           	     /* getNextSection xmlb is NULL !!! This is bad */
+              }
+                           
+              con->asynRCntl.escanInfo.prevtotl = con->asynRCntl.escanInfo.recdtotl ;
+
+              if((retcode =  pthread_mutex_unlock(&(con->asynRCntl.escanlock))) != 0){
+              	 printf(" getNextSection pthread lock return code %d\n",retcode) ;	
+              }
+              return(xmlb) ;
+          } else {
+          	  /* 
+          	   * backup before this tag 
+          	   */
+              workptr = workptr - tagval ;
+              if(workptr <= curptr){
+                 if (con->asynRCntl.escanInfo.prevtotl != con->asynRCntl.escanInfo.recdtotl){
+                 	  pthread_mutex_unlock(&(con->asynRCntl.escanlock));
+                 	  usleep(1000) ;
+                 	  toval++ ;
+                 	  if(toval > 5000)
+                 	     longjmp (save_env, 2);
+                 	  pthread_mutex_lock(&(con->asynRCntl.escanlock));
+                    workptr = LASTPTR(&(con->asynRCntl.escanInfo)) ;
+                    curptr  = CURPTR(&(con->asynRCntl.escanInfo));                	
+                 }
+              }
+              continue;
+          }
+        } else {
+           workptr-- ;
+           if(workptr <= curptr){
+              if (con->asynRCntl.escanInfo.prevtotl != con->asynRCntl.escanInfo.recdtotl){
+                 workptr = LASTPTR(&(con->asynRCntl.escanInfo)) ;
+                 curptr  = CURPTR(&(con->asynRCntl.escanInfo));
+              }
+           }
+        }
+     }
+  }
+  
+  if((retcode =  pthread_mutex_unlock(&(con->asynRCntl.escanlock))) != 0){
+     printf(" getNextSection pthread unlock return code %d\n",retcode) ;	
+  }
+  return(NULL) ;
+}
+/*
+ * check to see if the ending tag is at a 
+ * place in the data that we can use to 
+ * start parsing. The parsing needs to be
+ * given certain chunks of the data based on 
+ * the request we are processing. 
+ * If we see </CIM> thats good , we are 
+ * at the end of the data.
+ * return 0 if ending tag is OK
+ * return >0 if ending tag is not OK   
+ * CIM 
+ * VALUE.NAMEDINSTANCE
+ * CLASSNAME
+ *
+ */
+
+int checkTag(char * wrkptr , int methodtype ) {
+char * workptr = wrkptr ;
+char temptag[120] ;
+int  taglength = 1 ;
+
+   memset(&temptag[0] , 00 , 119) ;
+   /*
+    * find start of tag 
+    */
+   while(*workptr != '<'){ 
+      workptr-- ;
+      taglength++ ;
+   }
+	 	 
+	 
+	 if (strncmp(workptr , "</CIM>", 6) == 0) {
+	 	  return(0) ;
+	 }
+	 
+  switch(methodtype) {
+     case ENUMERATEINSTANCES:
+        if (strncmp(workptr , "</VALUE.NAMEDINSTANCE>", 22) == 0) {
+           return(0) ;
+        }
+        break ;
+     case ENUMERATEINSTANCENAMES:     	
+     	  if (strncmp(workptr , "</INSTANCENAME>", 15) == 0) {
+           return(0) ;
+        }
+        break;
+     case ENUMERATECLASSES:
+     	  if (strncmp(workptr , "</CLASS>", 8) == 0) {
+           return(0) ;
+        }
+        break;
+     case ENUMERATECLASSNAMES:
+     	  if (strncmp(workptr , "<CLASSNAME ", 11) == 0) {
+           return(0) ;
+        }
+        break; 	
+	 }
+	    
+	 /*
+	  * return the length of this tag 
+	  */
+	 strncpy(&temptag[0] , workptr , taglength) ;
+	 return(taglength) ;
+	 	
+}
+
+#endif
+
