@@ -56,7 +56,7 @@ void startParsing(ParserControl *parm)
 
 static void start(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp = {0};
 	ct = localLex(stateUnion, parm);
 	if(ct == XTOK_XML) {
 		ct = localLex(stateUnion, parm);
@@ -74,7 +74,7 @@ static void start(ParserControl *parm, parseUnion *stateUnion)
 
 static void cim(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp = {0};
 	ct = localLex(stateUnion, parm);
 	if(ct == XTOK_CIM) {
 		message(parm, (parseUnion*)&stateUnion->xtokMessage);
@@ -92,7 +92,7 @@ static void cim(ParserControl *parm, parseUnion *stateUnion)
 
 static void message(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp = {0};
 	ct = localLex((parseUnion*)&stateUnion->xtokMessage, parm);
 	if(ct == XTOK_MESSAGE) {
 		messageContent(parm, stateUnion);
@@ -110,7 +110,7 @@ static void message(ParserControl *parm, parseUnion *stateUnion)
 
 static void messageContent(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp = {0};
 	ct = localLex(stateUnion, parm);
 	if(ct == XTOK_SIMPLERSP) {
 		simpleRspContent(parm, (parseUnion*)&stateUnion->xtokSimpleRespContent);
@@ -137,7 +137,7 @@ static void messageContent(ParserControl *parm, parseUnion *stateUnion)
 
 static void simpleRspContent(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp ={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokSimpleRespContent, parm);
 	if(ct == XTOK_METHODRESP) {
 		methodRespContent(parm, (parseUnion*)&stateUnion->xtokSimpleRespContent.resp);
@@ -165,7 +165,7 @@ static void simpleRspContent(ParserControl *parm, parseUnion *stateUnion)
 
 static void exportIndication(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp = {0};
 	ct = localLex(stateUnion, parm);
 	if(ct == XTOK_EXPORTINDICATION) {
 		exParamValue(parm, stateUnion);
@@ -183,7 +183,7 @@ static void exportIndication(ParserControl *parm, parseUnion *stateUnion)
 
 static void exParamValue(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp = {0};
 	CMPIInstance *inst;
 	ct = localLex(stateUnion, parm);
 	if(ct == XTOK_EP_INSTANCE) {
@@ -211,7 +211,7 @@ static void exParamValue(ParserControl *parm, parseUnion *stateUnion)
 
 static void methodRespContent(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex(&lvalp, parm);
 	if(ct == XTOK_ERROR) {
 		dontLex = 1;
@@ -246,7 +246,7 @@ static void methodRespContent(ParserControl *parm, parseUnion *stateUnion)
 
 static void iMethodRespContent(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex(&lvalp, parm);
 	if(ct == XTOK_ERROR) {
 		dontLex = 1;
@@ -263,7 +263,7 @@ static void iMethodRespContent(ParserControl *parm, parseUnion *stateUnion)
 
 static void error(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp ={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokErrorResp, parm);
 	if(ct == XTOK_ERROR) {
 		setError(parm, &stateUnion->xtokErrorResp);
@@ -281,7 +281,7 @@ static void error(ParserControl *parm, parseUnion *stateUnion)
 
 static void returnValue(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp ={0};
 	CMPIType  t;
 	CMPIValue val;
 	CMPIInstance *inst;
@@ -321,7 +321,7 @@ static void returnValue(ParserControl *parm, parseUnion *stateUnion)
 
 static void returnValueData(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp ={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokReturnValueData, parm);
 	if(ct == XTOK_VALUE) {
 		dontLex = 1;
@@ -339,7 +339,7 @@ static void returnValueData(ParserControl *parm, parseUnion *stateUnion)
 
 static void paramValue(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokParamValue, parm);
 	if(ct == XTOK_PARAMVALUE) {
 		ct = localLex(&lvalp, parm);
@@ -369,7 +369,7 @@ static void paramValue(ParserControl *parm, parseUnion *stateUnion)
 
 static void paramValueData(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokParamValueData, parm);
 	if(ct == XTOK_VALUE) {
 		dontLex = 1;
@@ -400,7 +400,7 @@ static void paramValueData(ParserControl *parm, parseUnion *stateUnion)
 
 static void iReturnValue(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex(stateUnion, parm);
 	if(ct == XTOK_IRETVALUE) {
 		iReturnValueContent(parm, stateUnion);
@@ -418,7 +418,7 @@ static void iReturnValue(ParserControl *parm, parseUnion *stateUnion)
 
 static void iReturnValueContent(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp ={0};
 	CMPIObjectPath *op;
 	CMPIInstance *inst;
 	CMPIConstClass *cls;
@@ -524,7 +524,7 @@ static void iReturnValueContent(ParserControl *parm, parseUnion *stateUnion)
 
 static void getPropertyRetValue(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	CMPIType  t;
 	CMPIValue val;
 	ct = localLex((parseUnion*)&stateUnion->xtokGetPropRetContent, parm);
@@ -550,7 +550,7 @@ static void getPropertyRetValue(ParserControl *parm, parseUnion *stateUnion)
 
 static void valueObjectWithPath(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokObjectWithPath, parm);
 	if(ct == XTOK_VALUEOBJECTWITHPATH) {
 		valueObjectWithPathData(parm, (parseUnion*)&stateUnion->xtokObjectWithPath.object);
@@ -569,7 +569,7 @@ static void valueObjectWithPath(ParserControl *parm, parseUnion *stateUnion)
 
 static void valueObjectWithPathData(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	CMPIObjectPath *op;
 	CMPIInstance *inst;
 	ct = localLex((parseUnion*)&stateUnion->xtokObjectWithPathData, parm);
@@ -597,7 +597,7 @@ static void valueObjectWithPathData(ParserControl *parm, parseUnion *stateUnion)
 
 static void classWithPath(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokClassWithPath, parm);
 	if(ct == XTOK_CLASSPATH) {
 		dontLex = 1;
@@ -611,7 +611,7 @@ static void classWithPath(ParserControl *parm, parseUnion *stateUnion)
 
 static void instanceWithPath(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokInstanceWithPath, parm);
 	if(ct == XTOK_INSTANCEPATH) {
 		dontLex = 1;
@@ -625,7 +625,7 @@ static void instanceWithPath(ParserControl *parm, parseUnion *stateUnion)
 
 static void class(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokClass, parm);
 	if(ct == XTOK_CLASS) {
 		ct = localLex(&lvalp, parm);
@@ -678,7 +678,7 @@ static void class(ParserControl *parm, parseUnion *stateUnion)
 
 static void method(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokMethod, parm);
 	if(ct == XTOK_METHOD) {
 		ct = localLex(&lvalp, parm);
@@ -718,7 +718,7 @@ static void method(ParserControl *parm, parseUnion *stateUnion)
 
 static void methodData(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	if(ct == XTOK_PARAM) {
 		dontLex = 1;
 		if(ct == XTOK_PARAM) {
@@ -754,7 +754,7 @@ static void methodData(ParserControl *parm, parseUnion *stateUnion)
 
 static void parameter(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokParam, parm);
 	if(ct == XTOK_PARAM) {
 		ct = localLex(&lvalp, parm);
@@ -782,7 +782,7 @@ static void parameter(ParserControl *parm, parseUnion *stateUnion)
 
 static void parameterReference(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokParam, parm);
 	if(ct == XTOK_PARAMREF) {
 		ct = localLex(&lvalp, parm);
@@ -810,7 +810,7 @@ static void parameterReference(ParserControl *parm, parseUnion *stateUnion)
 
 static void parameterRefArray(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokParam, parm);
 	if(ct == XTOK_PARAMREFARRAY) {
 		ct = localLex(&lvalp, parm);
@@ -838,7 +838,7 @@ static void parameterRefArray(ParserControl *parm, parseUnion *stateUnion)
 
 static void parameterArray(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokParam, parm);
 	if(ct == XTOK_PARAMARRAY) {
 		ct = localLex(&lvalp, parm);
@@ -866,7 +866,7 @@ static void parameterArray(ParserControl *parm, parseUnion *stateUnion)
 
 static void objectPath(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokObjectPath, parm);
 	if(ct == XTOK_OBJECTPATH) {
 		instancePath(parm, (parseUnion*)&stateUnion->xtokObjectPath.path);
@@ -884,7 +884,7 @@ static void objectPath(ParserControl *parm, parseUnion *stateUnion)
 
 static void classPath(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokClassPath, parm);
 	if(ct == XTOK_CLASSPATH) {
 		nameSpacePath(parm, (parseUnion*)&stateUnion->xtokClassPath.name);
@@ -903,7 +903,7 @@ static void classPath(ParserControl *parm, parseUnion *stateUnion)
 
 static void className(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokClassName, parm);
 	if(ct == XTOK_CLASSNAME) {
 		ct = localLex((parseUnion*)&stateUnion->xtokClassName, parm);
@@ -920,7 +920,7 @@ static void className(ParserControl *parm, parseUnion *stateUnion)
 
 static void instancePath(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokInstancePath, parm);
 	if(ct == XTOK_INSTANCEPATH) {
 		nameSpacePath(parm, (parseUnion*)&stateUnion->xtokInstancePath.path);
@@ -939,7 +939,7 @@ static void instancePath(ParserControl *parm, parseUnion *stateUnion)
 
 static void localInstancePath(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokLocalInstancePath, parm);
 	if(ct == XTOK_LOCALINSTANCEPATH) {
 		localNameSpacePath(parm, (parseUnion*)&stateUnion->xtokLocalInstancePath.path);
@@ -958,7 +958,7 @@ static void localInstancePath(ParserControl *parm, parseUnion *stateUnion)
 
 static void nameSpacePath(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokNameSpacePath, parm);
 	if(ct == XTOK_NAMESPACEPATH) {
 		host(parm, (parseUnion*)&stateUnion->xtokNameSpacePath.host);
@@ -977,7 +977,7 @@ static void nameSpacePath(ParserControl *parm, parseUnion *stateUnion)
 
 static void host(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokHost, parm);
 	if(ct == XTOK_HOST) {
 		ct = localLex((parseUnion*)&stateUnion->xtokHost, parm);
@@ -994,7 +994,7 @@ static void host(ParserControl *parm, parseUnion *stateUnion)
 
 static void localNameSpacePath(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokLocalNameSpacePath, parm);
 	if(ct == XTOK_LOCALNAMESPACEPATH) {
 		ct = localLex(&lvalp, parm);
@@ -1031,7 +1031,7 @@ static void localNameSpacePath(ParserControl *parm, parseUnion *stateUnion)
 
 static void nameSpace(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokNameSpace, parm);
 	if(ct == XTOK_NAMESPACE) {
 		ct = localLex((parseUnion*)&stateUnion->xtokNameSpace, parm);
@@ -1048,7 +1048,7 @@ static void nameSpace(ParserControl *parm, parseUnion *stateUnion)
 
 static void valueNamedInstance(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokNamedInstance, parm);
 	if(ct == XTOK_VALUENAMEDINSTANCE) {
 		instanceName(parm, (parseUnion*)&stateUnion->xtokNamedInstance.path);
@@ -1067,7 +1067,7 @@ static void valueNamedInstance(ParserControl *parm, parseUnion *stateUnion)
 
 static void instance(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokInstance, parm);
 	if(ct == XTOK_INSTANCE) {
 		ct = localLex(&lvalp, parm);
@@ -1108,7 +1108,7 @@ static void instance(ParserControl *parm, parseUnion *stateUnion)
 
 static void genProperty(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokProperty, parm);
 	if(ct == XTOK_PROPERTY) {
 		dontLex = 1;
@@ -1132,7 +1132,7 @@ static void genProperty(ParserControl *parm, parseUnion *stateUnion)
 
 static void qualifier(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokQualifier, parm);
 	if(ct == XTOK_QUALIFIER) {
 		ct = localLex(&lvalp, parm);
@@ -1159,7 +1159,7 @@ static void qualifier(ParserControl *parm, parseUnion *stateUnion)
 
 static void qualifierData(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokQualifierData, parm);
 	if(ct == XTOK_VALUE) {
 		dontLex = 1;
@@ -1178,7 +1178,7 @@ static void qualifierData(ParserControl *parm, parseUnion *stateUnion)
 
 static void property(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokPropertyData, parm);
 	if(ct == XTOK_PROPERTY) {
 		ct = localLex(&lvalp, parm);
@@ -1214,7 +1214,7 @@ static void property(ParserControl *parm, parseUnion *stateUnion)
 
 static void propertyArray(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokPropertyData, parm);
 	if(ct == XTOK_PROPERTYARRAY) {
 		ct = localLex(&lvalp, parm);
@@ -1250,7 +1250,7 @@ static void propertyArray(ParserControl *parm, parseUnion *stateUnion)
 
 static void propertyReference(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokPropertyData, parm);
 	if(ct == XTOK_PROPERTYREFERENCE) {
 		ct = localLex(&lvalp, parm);
@@ -1286,7 +1286,7 @@ static void propertyReference(ParserControl *parm, parseUnion *stateUnion)
 
 static void instanceName(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokInstanceName, parm);
 	if(ct == XTOK_INSTANCENAME) {
 		ct = localLex(&lvalp, parm);
@@ -1315,7 +1315,7 @@ static void instanceName(ParserControl *parm, parseUnion *stateUnion)
 
 static void keyBinding(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokKeyBinding, parm);
 	if(ct == XTOK_KEYBINDING) {
 		keyBindingContent(parm, (parseUnion*)&stateUnion->xtokKeyBinding.val);
@@ -1334,7 +1334,7 @@ static void keyBinding(ParserControl *parm, parseUnion *stateUnion)
 
 static void keyBindingContent(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokKeyBindingContent, parm);
 	if(ct == XTOK_KEYVALUE) {
 		dontLex = 1;
@@ -1353,7 +1353,7 @@ static void keyBindingContent(ParserControl *parm, parseUnion *stateUnion)
 
 static void keyValue(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokKeyValue, parm);
 	if(ct == XTOK_KEYVALUE) {
 		ct = localLex((parseUnion*)&stateUnion->xtokKeyValue, parm);
@@ -1370,7 +1370,7 @@ static void keyValue(ParserControl *parm, parseUnion *stateUnion)
 
 static void value(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokValue, parm);
 	if(ct == XTOK_VALUE) {
 		valueData(parm, (parseUnion*)&stateUnion->xtokValue.data);
@@ -1389,7 +1389,7 @@ static void value(ParserControl *parm, parseUnion *stateUnion)
 
 static void valueData(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokValueData, parm);
 	if(ct == ZTOK_VALUE) {
 		stateUnion->xtokValueData.type=typeValue_charP;
@@ -1413,7 +1413,7 @@ static void valueData(ParserControl *parm, parseUnion *stateUnion)
 
 static void valueArray(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokValueArray, parm);
 	if(ct == XTOK_VALUEARRAY) {
 		ct = localLex(&lvalp, parm);
@@ -1446,7 +1446,7 @@ static void valueArray(ParserControl *parm, parseUnion *stateUnion)
 
 static void valueRefArray(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokValueRefArray, parm);
 	if(ct == XTOK_VALUEREFARRAY) {
 		ct = localLex(&lvalp, parm);
@@ -1479,7 +1479,7 @@ static void valueRefArray(ParserControl *parm, parseUnion *stateUnion)
 
 static void valueReference(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokValueReference, parm);
 	if(ct == XTOK_VALUEREFERENCE) {
 		valueReferenceData(parm, (parseUnion*)&stateUnion->xtokValueReference.data);
@@ -1498,7 +1498,7 @@ static void valueReference(ParserControl *parm, parseUnion *stateUnion)
 
 static void valueReferenceData(ParserControl *parm, parseUnion *stateUnion)
 {
-	parseUnion lvalp;
+	parseUnion lvalp={0};
 	ct = localLex((parseUnion*)&stateUnion->xtokValueReferenceData, parm);
 	if(ct == XTOK_INSTANCEPATH) {
 		dontLex = 1;
