@@ -1,6 +1,6 @@
 
 /*
- * $Id: cimcft.h,v 1.2 2007/03/15 14:16:01 mihajlov Exp $
+ * $Id: cimcft.h,v 1.6 2008/09/09 15:13:09 smswehla Exp $
  *
  * © Copyright IBM Corp. 2007
  *
@@ -64,6 +64,7 @@ extern "C" {
 				    CIMCStatus * rc);
     CIMCCount (*getPropQualifierCount) (CIMCClass * cc, const char * prop, CIMCStatus * rc);
    
+    CIMCString *(*getSuperClassName) (CIMCClass * cc, CIMCStatus * rc);
     CIMCArray *(*getKeyList) (CIMCClass * cc);
     char *(*toString) (CIMCClass * cc);     
     void (*relocate) (CIMCClass * cc);
@@ -694,7 +695,58 @@ extern "C" {
       (CIMCDateTime* dt, CIMCStatus* rc);
   };
 
+  /** This structure represents the indication listener object.
+   */
+  struct _CIMCIndicationListener {
 
+    /** Opaque pointer to MB specific implementation data.
+     */
+    void *hdl;
+
+    /** Pointer to the indication listener Function Table.
+     */
+    CIMCIndicationListenerFT* ft;
+  };
+
+
+  /** This structure is a table of pointers providing access to indication
+      listener support sevices.
+  */
+  struct _CIMCIndicationListenerFT {
+
+    /** Function table version
+     */
+    int ftVersion;
+
+    /** The indication listener object will not be used any further and may 
+        be freed by CIMC run time system.
+	@param il pointer to this indication listener
+	@return Service return status.
+    */
+    CIMCStatus (*release)
+      (CIMCIndicationListener* il);
+
+    /** Create an independent copy of this indication listener object. The
+	resulting object must be released explicitly.
+	@param il pointer to this indication listener
+	@param rc Output: Service return status (suppressed when NULL).
+	@return Pointer to copied indication listener object.
+    */
+    CIMCIndicationListener* (*clone)
+      (CIMCIndicationListener* il, CIMCStatus* rc);
+
+    /** Start listening.
+	@param il pointer to this indication listener.
+    */
+    CIMCStatus (*start)
+      (CIMCIndicationListener* il);
+      
+    /** Stop listening.
+    @param il pointer to this indication listener.
+    */
+    CIMCStatus (*stop)
+      (CIMCIndicationListener* il);      
+  };
 #ifdef __cplusplus
 };
 #endif
